@@ -217,11 +217,6 @@ def comb_recall(
         err = ae
     elif error == 're':
         err = re
-    if len(hist_achieved) == 1:
-        return float(err(achieved, desired) < tolerance) * a \
-            - float(
-                err(hist_achieved[-1], hist_desired[-1]) >= -float('inf')
-                ) * b
     return float(err(achieved, desired) < tolerance) * a \
         - float(
             err(hist_achieved[-1], hist_desired[-1]) >= err(hist_achieved[-2], hist_desired[-2])
@@ -449,6 +444,9 @@ class Track(Task):
         return self._observation.astype(physics.state_dtype)
 
     def reward(self, physics: Physics) -> float:
+        if self.reward_func.__name__ == 'comb_recall':
+            self.reward_kwargs['hist_achieved'] = self._observations
+            self.reward_kwargs['hist_desired'] = self._references
         self._reward = self.reward_func(
             self._observation,
             self._reference,
